@@ -4,6 +4,8 @@ from dragonfly.model import Model as DFModel
 
 from ladybug.analysisperiod import AnalysisPeriod
 
+from honeybee_energy.construction.window import WindowConstruction
+
 from .polygon import Polygon
 from .compliance import ComplianceData
 from .sitebldg import SiteBldgData
@@ -11,6 +13,7 @@ from .title import Title
 from .run_period import RunPeriod
 from .construction import Construction, ConstructionCollection
 from .floor_space import Floor
+from .glass_types import GlassType
 
 from . import blocks as fb
 
@@ -20,7 +23,7 @@ class Model:
 
     def __init__(
             self, title, run_period=None, compliance_data=None, site_building_data=None,
-            polygons=None, constructions=None, floors=None
+            polygons=None, constructions=None, floors=None, glass_types=None
     ) -> None:
         self.title = title
         self.run_period = run_period
@@ -29,6 +32,7 @@ class Model:
         self.polygons = polygons
         self.constructions = constructions
         self.floors = floors
+        self.glass_types = glass_types
 
     @classmethod
     def from_df_model(cls, df_model: DFModel, run_period=None):
@@ -37,8 +41,12 @@ class Model:
 
         polygons = []
         flr_spc = []
+        window_constructions = []
+        for con_set in df_model.properties.energy.construction_sets:
+            window_constructions.append(con_set.aperture_set.window_construction)
         for building in df_model.buildings:
             for story in building.all_stories():
+
                 flr_spc.append(Floor.from_story(story))
                 polygons.append(Polygon.from_story(story))
                 for room in story:
@@ -46,9 +54,11 @@ class Model:
 
         constructions = ConstructionCollection.from_hb_constructions(
             df_model.properties.energy.constructions)
+        glass_types = [GlassType.from_hb_window_constr(
+            w_con) for w_con in window_constructions]
 
         return cls(df_model.display_name, run_period, polygons=polygons,
-                   constructions=constructions, floors=flr_spc)
+                   constructions=constructions, floors=flr_spc, glass_types=glass_types)
 
     @classmethod
     def from_dfjson(cls, dfjson_file, run_period=None):
@@ -126,6 +136,14 @@ class Model:
     def constructions(self, value):
         self._constructions = value
 
+    @property
+    def glass_types(self):
+        return self._glass_types
+
+    @glass_types.setter
+    def glass_types(self, value):
+        self._glass_types = value
+
     def to_inp(self):
 
         data = [
@@ -137,7 +155,7 @@ class Model:
             self.site_bldg_data.to_inp(),
             self.constructions.to_inp(),
             fb.glzCode,
-            fb.glzTyp,
+            '\n'.join(gt.to_inp() for gt in self.glass_types),
             fb.polygons,
             '\n'.join(pl.to_inp() for pl in self.polygons),
             fb.wallParams,
